pub enum TableComponent {
Show 21 variants
LeftBorder,
RightBorder,
TopBorder,
BottomBorder,
LeftHeaderIntersection,
HeaderLines,
MiddleHeaderIntersections,
RightHeaderIntersection,
VerticalLines,
HorizontalLines,
MiddleIntersections,
LeftBorderIntersections,
RightBorderIntersections,
TopBorderIntersections,
BottomBorderIntersections,
BottomBorderColspanIntersections,
MiddleHeaderMergeIntersection,
TopLeftCorner,
TopRightCorner,
BottomLeftCorner,
BottomRightCorner,
}Expand description
All configurable table components. A character can be assigned to each component via Table::set_style. This is then used to draw character of the respective component to the commandline.
I hope that most component names are self-explanatory. Just in case: BorderIntersections are Intersections, where rows/columns lines meet outer borders. E.g.:
---------
v |
+---+---+---+ |
| a | b | c | |
+===+===+===+<-|
| | | | |
+---+---+---+<-- These "+" chars are Borderintersections.
| | | | The inner "+" chars are MiddleIntersections
+---+---+---+Variants
LeftBorder
RightBorder
TopBorder
BottomBorder
LeftHeaderIntersection
HeaderLines
MiddleHeaderIntersections
RightHeaderIntersection
VerticalLines
HorizontalLines
MiddleIntersections
LeftBorderIntersections
RightBorderIntersections
TopBorderIntersections
BottomBorderIntersections
BottomBorderColspanIntersections
Used at the bottom border where a colspan cell merges columns above. Typically renders as ‘─’ to create a continuous line instead of ‘┴’.
MiddleHeaderMergeIntersection
Used at the header separator where a colspan or rowspan starts in the row below. This character should have a top connector (to vertical line in header) and horizontal continuation, but no bottom connector since the column boundary does not continue into the data rows. Typically renders as ‘╧’ for UTF-8 (up single and horizontal double) or ‘=’ for ASCII.
TopLeftCorner
TopRightCorner
BottomLeftCorner
BottomRightCorner
Implementations
Sourceimpl TableComponent
impl TableComponent
pub fn iter() -> impl Iterator<Item = TableComponent>